pub struct LatinSquare { /* private fields */ }Expand description
A Latin square of order n.
A Latin square is an n x n array with symbols {0..n-1} such that
each row and each column is a permutation of {0..n-1}.
Implementations